@@ -1,3 +1,12 @@
+#  File ergm/R/ergm.MCMCse.R
+#  Part of the statnet package, http://statnetproject.org
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) in
+#    http://statnetproject.org/attribution
+#
+#  Copyright 2011 the statnet development team
+######################################################################
 #############################################################################
 # The <ergm.MCMCse> function computes and returns the MCMC standard errors 
 #
@@ -130,12 +139,17 @@ ergm.MCMCse<-function(theta, theta0, statsmatrix, statsmatrix.miss,
   if(all(dim(H)==c(0,0))){
     hessian <- matrix(NA, ncol=length(theta), nrow=length(theta))
     mc.se <- rep(NA,length=length(theta))
-    return(mc.se)
+    return(list(mc.se=mc.se))
   }
   cov.zbar <- cov.zbar[!novar,,drop=FALSE] 
   cov.zbar <- cov.zbar[,!novar,drop=FALSE] 
   mc.se <- rep(NA,length=length(theta))
   mc.se0 <- try(solve(H, cov.zbar), silent=TRUE)
+  if(length(novar)==length(offsettheta)){
+   novar <- novar | offsettheta
+  }else{
+   novar <- novar[!offsettheta]
+  }
   if(!(inherits(mc.se0,"try-error"))){
     mc.se0 <- try(diag(solve(H, t(mc.se0))), silent=TRUE)
     if(!(inherits(mc.se0,"try-error"))){
@@ -144,15 +158,15 @@ ergm.MCMCse<-function(theta, theta0, statsmatrix, statsmatrix.miss,
         if(!(inherits(mc.se.miss0,"try-error"))){
           mc.se.miss0 <- try(diag(solve(H.miss, t(mc.se.miss0))), silent=TRUE)
           if(!inherits(mc.se.miss0,"try-error")){
-            mc.se[!offsettheta][!novar] <- sqrt(mc.se0 + mc.se.miss0)
+            mc.se[!novar] <- sqrt(mc.se0 + mc.se.miss0)
           }else{
-            mc.se[!offsettheta][!novar] <- sqrt(mc.se0)
+            mc.se[!novar] <- sqrt(mc.se0)
           }
         }else{
-          mc.se[!offsettheta][!novar] <- sqrt(mc.se0)
+          mc.se[!novar] <- sqrt(mc.se0)
         }
       }else{
-        mc.se[!offsettheta][!novar] <- sqrt(mc.se0)
+        mc.se[!novar] <- sqrt(mc.se0)
       }
     }
   }
