@@ -1,3 +1,12 @@
+#  File ergm/R/ergm.llik.R
+#  Part of the statnet package, http://statnetproject.org
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) in
+#    http://statnetproject.org/attribution
+#
+#  Copyright 2011 the statnet development team
+######################################################################
 #=================================================================================
 # This file contains the following 14 functions for computing log likelihoods,
 # gradients, hessians, and such:
@@ -61,16 +70,16 @@ llik.fun <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
   eta <- ergm.eta(theta.offset, etamap)
 
   # Calculate approximation to l(eta) - l(eta0) using a lognormal approximation
-  x <- eta-eta0
+  etaparam <- eta-eta0
 # MSH: Is this robust?
-  x <- x[!etamap$offsetmap]
+  etaparam <- etaparam[!etamap$offsetmap]
   xsim <- xsim[,!etamap$offsetmap, drop=FALSE]
   xobs <- xobs[!etamap$offsetmap]
   #
-  basepred <- xsim %*% x
+  basepred <- xsim %*% etaparam
   mb <- sum(basepred*probs)
   vb <- sum(basepred*basepred*probs) - mb*mb
-  llr <- sum(xobs * x) - mb - varweight*vb
+  llr <- sum(xobs * etaparam) - mb - varweight*vb
   #
 
   # Simplistic error control;  -800 is effectively like -Inf:
@@ -92,9 +101,9 @@ llik.fun <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
 #  theta.offset <- etamap$theta0
 #  theta.offset[!etamap$offsettheta] <- theta
 #  eta <- ergm.eta(theta.offset, etamap)
-#  x <- eta-eta0
+#  etaparam <- eta-eta0
 #  xsim[,etamap$offsetmap] <- 0
-#  basepred <- xsim %*% x
+#  basepred <- xsim %*% etaparam
 #  prob <- max(basepred)
 #  prob <- probs*exp(basepred - prob)
 #  prob <- prob/sum(prob)
@@ -129,15 +138,15 @@ llik.grad <- function(theta, xobs, xsim, probs,  xsim.miss=NULL, probs.miss=NULL
   theta.offset[!etamap$offsettheta] <- theta
   eta <- ergm.eta(theta.offset, etamap)
 # etagrad <- ergm.etagrad(theta.offset, etamap)
-  x <- eta-eta0
+  etaparam <- eta-eta0
 # MSH: Is this robust?
-  x <- x[!etamap$offsetmap]
+  etaparam <- etaparam[!etamap$offsetmap]
   xsim <- xsim[,!etamap$offsetmap, drop=FALSE]
   xobs <- xobs[!etamap$offsetmap]
 # etagrad <- etagrad[,!etamap$offsetmap,drop=FALSE]
 # etagrad <- etagrad[!etamap$offsettheta,,drop=FALSE]
 #
-  basepred <- xsim %*% x
+  basepred <- xsim %*% etaparam
   prob <- max(basepred)
   prob <- probs*exp(basepred - prob)
   prob <- prob/sum(prob)
@@ -176,7 +185,7 @@ llik.hessian <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NU
                          varweight=0.5, trustregion=20, eta0, etamap){
   theta.offset <- etamap$theta0
   theta.offset[!etamap$offsettheta] <- theta
-  namesx <- names(theta)
+  namestheta <- names(theta)
 # xsim[,etamap$offsettheta] <- 0
 #
 #    eta transformation
@@ -191,7 +200,7 @@ llik.hessian <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NU
 # etagrad <- etagrad[,!etamap$offsetmap,drop=FALSE]
 # etagrad <- etagrad[!etamap$offsettheta,,drop=FALSE]
 #
-# x <- x[!etamap$offsettheta]
+# etaparam <- etaparam[!etamap$offsettheta]
   basepred <- xsim %*% x
   prob <- max(basepred)
   prob <- probs*exp(basepred - prob)
@@ -214,10 +223,11 @@ llik.hessian <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NU
 # htmp <- tcrossprod(htmp, etagrad)
 # H <- crossprod(htmp, htmp)
 # H <- crossprod(t(etagrad),crossprod(H, t(etagrad)))
-  He <- matrix(NA, ncol = length(etamap$offsettheta), 
-                   nrow = length(etamap$offsettheta))
-  He[!etamap$offsettheta, !etamap$offsettheta] <- H
-  dimnames(He) <- list(names(namesx), names(namesx))
+# He <- matrix(NA, ncol = length(etamap$offsettheta), 
+#                  nrow = length(etamap$offsettheta))
+# He[!etamap$offsettheta, !etamap$offsettheta] <- H
+  He <- H[!etamap$offsettheta, !etamap$offsettheta]
+  dimnames(He) <- list(names(namestheta), names(namestheta))
 # H
   He
 }
@@ -237,7 +247,7 @@ llik.hessian <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NU
 
 llik.hessian.naive <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
                                varweight=0.5, eta0, etamap){
-  namesx <- names(theta)
+  namestheta <- names(theta)
   xsim <- xsim[,!etamap$offsettheta, drop=FALSE]
   eta <- ergm.eta(theta, etamap)
   etagrad <- ergm.etagrad(theta, etamap)
@@ -245,9 +255,9 @@ llik.hessian.naive <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.m
   # It does not matter if we subtract a constant from the (eta-eta0)^t g vector
   # prior to exponentiation.  So subtract to make maximum value = 0 for 
   # the sake of numberical stability:
-  x <- eta-eta0
-  x <- x[!etamap$offsettheta]
-  basepred <- xsim %*% x
+  etaparam <- eta-eta0
+  etaparam <- etaparam[!etamap$offsettheta]
+  basepred <- xsim %*% etaparam
   w <- probs * exp(basepred - max(basepred))
   w <- w/sum(w)
   wtxsim <- sweep(xsim, 1, w, "*")
@@ -259,7 +269,7 @@ llik.hessian.naive <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.m
   H <- - crossprod(etagrad, crossprod(H, etagrad))
   He <- matrix(NA, ncol = length(theta), nrow = length(theta))
   He[!etamap$offsettheta, !etamap$offsettheta] <- H
-  dimnames(He) <- list(names(namesx), names(namesx))
+  dimnames(He) <- list(names(namestheta), names(namestheta))
   He
 }
 
@@ -270,9 +280,9 @@ llik.hessian.naive <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.m
 # llik.exp <- function(theta, xobs, xsim, probs, 
 #                      varweight=0.5, eta0, etamap){
 #   eta <- ergm.eta(theta, etamap)
-#   x <- eta-eta0
+#   etaparam <- eta-eta0
 #   vb <- var(xsim)
-#   llr <- -sum(xobs * x) + varweight*(t(x) %*% vb %*% x)
+#   llr <- -sum(xobs * etaparam) + varweight*(t(etaparam) %*% vb %*% etaparam)
 #   if(is.infinite(llr) | is.na(llr)){llr <- -800}
 #   llr
 # }
@@ -304,7 +314,7 @@ llik.fun.EF <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NUL
   llr <- llr - 2*(llr-trustregion)*(llr>trustregion)
 #
 # cat(paste("max, log-lik",maxbase,llr,"\n"))
-# aaa <- sum(xobs * x) - log(sum(probs*exp(xsim %*% x)))
+# aaa <- sum(xobs * etaparam) - log(sum(probs*exp(xsim %*% etaparam)))
 # cat(paste("log-lik",llr,aaa,"\n"))
 # aaa
   llr
@@ -322,10 +332,10 @@ llik.fun.EF <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NUL
 llik.fun2 <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL, 
                       varweight=0.5, trustregion=20, eta0, etamap){
   eta <- ergm.eta(theta, etamap)
-  x <- eta-eta0
-  basepred <- xsim %*% x
+  etaparam <- eta-eta0
+  basepred <- xsim %*% etaparam
   maxbase <- max(basepred)
-  llr <- sum(xobs * x) - maxbase - log(sum(probs*exp(basepred-maxbase)))
+  llr <- sum(xobs * etaparam) - maxbase - log(sum(probs*exp(basepred-maxbase)))
   llr
 }
 
@@ -340,8 +350,8 @@ llik.fun2 <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
 llik.grad2 <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
                        varweight=0.5, trustregion=20, eta0, etamap){
   eta <- ergm.eta(theta, etamap)
-  x <- eta-eta0
-  basepred <- xsim %*% x
+  etaparam <- eta-eta0
+  basepred <- xsim %*% etaparam
   prob <- max(basepred)
   prob <- probs*exp(basepred - prob)
   prob <- prob/sum(prob)
@@ -449,18 +459,18 @@ llik.fun.median <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss
   # Calculate approximation to l(eta) - l(eta0) using a lognormal approximation
   # i.e., assuming that the network statistics are approximately normally 
   # distributed so that exp(eta * stats) is lognormal
-  x <- eta-eta0
+  etaparam <- eta-eta0
 # MSH: Is this robust?
-  x <- x[!etamap$offsetmap]
+  etaparam <- etaparam[!etamap$offsetmap]
   xsim <- xsim[,!etamap$offsetmap, drop=FALSE]
   xobs <- xobs[!etamap$offsetmap]
 # The next line is right!
-# aaa <- sum(xobs * x) - log(sum(probs*exp(xsim %*% x)))
+# aaa <- sum(xobs * etaparam) - log(sum(probs*exp(xsim %*% etaparam)))
 # These lines standardize:
-  basepred <- xsim %*% x
+  basepred <- xsim %*% etaparam
 #
 # maxbase <- max(basepred)
-# llr <- sum(xobs * x) - maxbase - log(sum(probs*exp(basepred-maxbase)))
+# llr <- sum(xobs * etaparam) - maxbase - log(sum(probs*exp(basepred-maxbase)))
 #
 # alternative based on log-normal approximation
   mb <- wtd.median(basepred, weight=probs)
@@ -468,7 +478,7 @@ llik.fun.median <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss
 # 
 # This is the log-likelihood ratio (and not its negative)
 #
-  llr <- sum(xobs * x) - (mb + varweight*sdb*sdb)
+  llr <- sum(xobs * etaparam) - (mb + varweight*sdb*sdb)
   if(is.infinite(llr) | is.na(llr)){llr <- -800}
 #
 # Penalize changes to trustregion
@@ -476,7 +486,7 @@ llik.fun.median <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss
   llr <- llr - 2*(llr-trustregion)*(llr>trustregion)
 #
 # cat(paste("max, log-lik",maxbase,llr,"\n"))
-# aaa <- sum(xobs * x) - log(sum(probs*exp(xsim %*% x)))
+# aaa <- sum(xobs * etaparam) - log(sum(probs*exp(xsim %*% etaparam)))
 # cat(paste("log-lik",llr,aaa,"\n"))
 # aaa
   llr
